@@ -87,15 +87,11 @@ Loverl::Create::Directory - Creates the project directory
 
 =head1 VERSION
 
-version 0.002
-
-=head1 SYNOPSIS
-
-    loverl new [New Project Name]
+version 0.003
 
 =head1 DESCRIPTION
 
-Loverl's new command will initialize the LÖVE2D project directory.
+The Directory module creates the project folder.
 
 =head1 AUTHOR
 
