@@ -100,15 +100,11 @@ Loverl::Create::File_Content - Will be used when preocessing file content
 
 =head1 VERSION
 
-version 0.002
-
-=head1 SYNOPSIS
-
-    loverl new [New Project Name]
+version 0.003
 
 =head1 DESCRIPTION
 
-Loverl's new command will initialize the LÖVE2D project directory.
+THe File Content Module is called by the Directory module write to to the proper files.
 
 =head1 AUTHOR
 
